Crate classic_test_tube

Crate classic_test_tube 

classic-test-tube

a library for testing your smart contract against simulated classic chain logic. This library will allow smart contract developers to test contract against real chain logic without the need for spinning up a node. This will save tremendous amount of time by rapid testing.

To generate C header for use by test-tube go tool cgo -exportheader artifacts/libclassictesttube.docrs.h main.go

running classic-test-tube on darwin/arm64

check go version that it supports darwin/arm64

cargo clean
cargo build

Re-exports

pub use classic_rust;

Macros

fn_execute
fn_query

Structs

Bank
ExecuteResponse
Market
NonSigningAccount
Oracle
SigningAccount
TerraTestApp
Treasury
Wasm

Enums

DecodeError
EncodeError
FeeSetting
RunnerError

Traits

Account
Module
Runner

Type Aliases

RunnerExecuteResult
RunnerResult